==> txtwrap-3.0.1.tar.gz: txtwrap-3.0.1/txtwrap/constants.py <==
LOREM_IPSUM_WORDS = 'Lorem ipsum odor amet, consectetuer adipiscing elit.'
LOREM_IPSUM_SENTENCES = (
    'Lorem ipsum odor amet, consectetuer adipiscing elit. In malesuada eros natoque urna felis diam aptent donec. Cubil'
    'ia libero morbi fusce tempus, luctus aenean augue. Mus senectus rutrum phasellus fusce dictum platea. Eros a integ'
    'er nec fusce erat urna.'
)
LOREM_IPSUM_PARAGRAPHS = (
    'Lorem ipsum odor amet, consectetuer adipiscing elit. Nulla porta ex condimentum velit facilisi; consequat congue. '
    'Tristique duis sociosqu aliquam semper sit id. Nisi morbi purus, nascetur elit pellentesque venenatis. Velit commo'
    'do molestie potenti placerat faucibus convallis. Himenaeos dapibus ipsum natoque nam dapibus habitasse diam. Viver'
    'ra ac porttitor cras tempor cras. Pharetra habitant nibh dui ipsum scelerisque cras? Efficitur phasellus etiam con'
    'gue taciti tortor quam. Volutpat quam vulputate condimentum hendrerit justo congue iaculis nisl nullam.\n\nIncepto'
    's tempus nostra fringilla arcu; tellus blandit facilisi risus. Platea bibendum tristique lectus nunc placerat id a'
    'liquam. Eu arcu nisl mattis potenti elementum. Dignissim vivamus montes volutpat litora felis fusce ultrices. Vulp'
    'utate magna nascetur bibendum inceptos scelerisque morbi posuere. Consequat dolor netus augue augue tristique cura'
    'bitur habitasse bibendum. Consectetur est per eros semper, magnis interdum libero. Arcu adipiscing litora metus fr'
    'ingilla varius gravida congue tellus adipiscing. Blandit nulla mauris nullam ante metus curae scelerisque.\n\nSem '
    'varius sodales ut volutpat imperdiet turpis primis nullam. At gravida tincidunt phasellus lacus duis integer eros '
    'penatibus. Interdum mauris molestie posuere nascetur dignissim himenaeos; magna et quisque. Dignissim malesuada et'
    'iam donec vehicula aliquet bibendum. Magna dapibus sapien semper parturient id dis? Pretium orci ante leo, porta t'
    'incidunt molestie. Malesuada dictumst commodo consequat interdum nisi fusce cras rhoncus feugiat.\n\nHimenaeos mat'
    'tis commodo suspendisse maecenas cras arcu. Habitasse id facilisi praesent justo molestie felis luctus suspendisse'
    '. Imperdiet ipsum praesent nunc mauris mattis curabitur. Et consectetur morbi auctor feugiat enim ridiculus arcu. '
    'Ultricies magna blandit eget; vivamus sollicitudin nisl proin. Sollicitudin sociosqu et finibus elit vestibulum sa'
    'pien nec odio euismod. Turpis eleifend amet quis auctor cursus. Vehicula pharetra sapien praesent amet purus ante.'
    ' Risus blandit cubilia lorem hendrerit penatibus in magnis.\n\nAmet posuere nunc; maecenas consequat risus potenti'
    '. Volutpat leo lacinia sapien nulla sagittis dignissim mauris ultrices aliquet. Nisi pretium interdum luctus donec'
    ' magna suscipit. Dapibus tristique felis natoque malesuada augue? Justo faucibus tincidunt congue arcu sem; fusce '
    'aliquet proin. Commodo neque nibh; tempus ad tortor netus. Mattis ultricies nec maximus porttitor non mauris?'
)

SEPARATOR_WHITESPACE = (' ', '\t', '\n', '\r', '\v', '\f')
SEPARATOR_ESCAPE = SEPARATOR_WHITESPACE + ('\a', '\b', '\0')

==> txtwrap-3.1.0.tar.gz: txtwrap-3.1.0/txtwrap/constants.py <==
import re

LOREM_IPSUM_WORDS = 'Lorem ipsum odor amet, consectetuer adipiscing elit.'
LOREM_IPSUM_SENTENCES = (
    'Lorem ipsum odor amet, consectetuer adipiscing elit. In malesuada eros natoque urna felis diam aptent donec. Cubil'
    'ia libero morbi fusce tempus, luctus aenean augue. Mus senectus rutrum phasellus fusce dictum platea. Eros a integ'
    'er nec fusce erat urna.'
)
LOREM_IPSUM_PARAGRAPHS = (
    'Lorem ipsum odor amet, consectetuer adipiscing elit. Nulla porta ex condimentum velit facilisi; consequat congue. '
    'Tristique duis sociosqu aliquam semper sit id. Nisi morbi purus, nascetur elit pellentesque venenatis. Velit commo'
    'do molestie potenti placerat faucibus convallis. Himenaeos dapibus ipsum natoque nam dapibus habitasse diam. Viver'
    'ra ac porttitor cras tempor cras. Pharetra habitant nibh dui ipsum scelerisque cras? Efficitur phasellus etiam con'
    'gue taciti tortor quam. Volutpat quam vulputate condimentum hendrerit justo congue iaculis nisl nullam.\n\nIncepto'
    's tempus nostra fringilla arcu; tellus blandit facilisi risus. Platea bibendum tristique lectus nunc placerat id a'
    'liquam. Eu arcu nisl mattis potenti elementum. Dignissim vivamus montes volutpat litora felis fusce ultrices. Vulp'
    'utate magna nascetur bibendum inceptos scelerisque morbi posuere. Consequat dolor netus augue augue tristique cura'
    'bitur habitasse bibendum. Consectetur est per eros semper, magnis interdum libero. Arcu adipiscing litora metus fr'
    'ingilla varius gravida congue tellus adipiscing. Blandit nulla mauris nullam ante metus curae scelerisque.\n\nSem '
    'varius sodales ut volutpat imperdiet turpis primis nullam. At gravida tincidunt phasellus lacus duis integer eros '
    'penatibus. Interdum mauris molestie posuere nascetur dignissim himenaeos; magna et quisque. Dignissim malesuada et'
    'iam donec vehicula aliquet bibendum. Magna dapibus sapien semper parturient id dis? Pretium orci ante leo, porta t'
    'incidunt molestie. Malesuada dictumst commodo consequat interdum nisi fusce cras rhoncus feugiat.\n\nHimenaeos mat'
    'tis commodo suspendisse maecenas cras arcu. Habitasse id facilisi praesent justo molestie felis luctus suspendisse'
    '. Imperdiet ipsum praesent nunc mauris mattis curabitur. Et consectetur morbi auctor feugiat enim ridiculus arcu. '
    'Ultricies magna blandit eget; vivamus sollicitudin nisl proin. Sollicitudin sociosqu et finibus elit vestibulum sa'
    'pien nec odio euismod. Turpis eleifend amet quis auctor cursus. Vehicula pharetra sapien praesent amet purus ante.'
    ' Risus blandit cubilia lorem hendrerit penatibus in magnis.\n\nAmet posuere nunc; maecenas consequat risus potenti'
    '. Volutpat leo lacinia sapien nulla sagittis dignissim mauris ultrices aliquet. Nisi pretium interdum luctus donec'
    ' magna suscipit. Dapibus tristique felis natoque malesuada augue? Justo faucibus tincidunt congue arcu sem; fusce '
    'aliquet proin. Commodo neque nibh; tempus ad tortor netus. Mattis ultricies nec maximus porttitor non mauris?'
)

SEPARATOR_WHITESPACE = r' |\t|\n|\r|\v|\f'
SEPARATOR_ESCAPE = SEPARATOR_WHITESPACE + r'|\a|\x08|\0'  # \x08 -> \b
SEPARATOR_NEWLINE = r'\r\n|\n|\r'
SEPARATOR_NEWLINE_AND_BREAK = (r'</?br\s*/?>|' + SEPARATOR_NEWLINE, re.IGNORECASE)
